/*******************************************************************************
 * University of Illinois/NCSA
 * Open Source License
 *
 * Copyright (c) 2010 , NCSA.  All rights reserved.
 *
 * Developed by:
 * Cyberenvironments and Technologies (CET)
 * http://cet.ncsa.illinois.edu/
 *
 * National Center for Supercomputing Applications (NCSA)
 * http://www.ncsa.illinois.edu/
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of CET, University of Illinois/NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 *******************************************************************************/
package edu.uiuc.ncsa.cet.bean;

import java.util.Date;

/**
 * This is a minimal dataset. This is used to store information about previews
 * created and associated with the real dataset.
 * 
 * @author Rob Kooper
 * 
 */
@SuppressWarnings("serial")
public class PreviewBean extends CETBean
{
    /** Date the preview is created */
    private Date       date     = new Date();

    /** creator of the preview */
    private PersonBean creator  = null;

    /** Mime type of the data */
    private String     mimetype = "";        //$NON-NLS-1$

    /** size of the blob associated, -1 means unknown size, -2 means no blob */
    private long       size     = -1;

    /**
     * Create a new instance of the artifact.
     */
    public PreviewBean()
    {
    }

    /**
     * Return the date when the preview was created.
     * 
     * @return date the preview was created.
     */
    public Date getDate()
    {
        return date;
    }

    /**
     * Sets the date when the preview was created.
     * 
     * @param date
     *            sets the date when the preview was created.
     * 
     */
    public void setDate( Date date )
    {
        this.date = date;
    }

    /**
     * Return the PersonBean that is the creator of the preview
     * 
     * @return PersonBean that represents the creator
     */
    public PersonBean getCreator()
    {
        return creator;
    }

    /**
     * Sets the PersonBean that represents the creator of the preview.
     * 
     * @param creator
     *            sets the PersonBeans that represents the creator of the
     *            preview.
     * 
     */
    public void setCreator( PersonBean creator )
    {
        this.creator = creator;
    }

    /**
     * Return the mime type of the preview.
     * 
     * @return mime type of the preview
     */
    public String getMimeType()
    {
        return mimetype;
    }

    /**
     * Sets the mime type of the preview
     * 
     * @param mimetype
     *            sets the mime type of the preview
     * 
     */
    public void setMimeType( String mimetype )
    {
        this.mimetype = mimetype;
    }

    /**
     * Returns the size of the blob, this is -2 if there is no blob associated
     * or -1 if the size has not been computed.
     * 
     * @return the size
     */
    public long getSize()
    {
        return size;
    }

    /**
     * Sets the size of the blob, this can be set to -2 if there is no blob
     * associated with this dataset.
     * 
     * @param size
     *            the size to set
     */
    public void setSize( long size )
    {
        this.size = size;
    }
}
